package envoy.server.processors;

import java.io.IOException;

import envoy.data.IDGenerator;
import envoy.event.IDGeneratorRequest;
import envoy.server.data.ConfigItem;
import envoy.server.data.PersistenceManager;
import envoy.server.net.ObjectWriteProxy;

/**
 * Project: <strong>envoy-server-standalone</strong><br>
 * File: <strong>IDGeneratorRequestProcessor.java</strong><br>
 * Created: <strong>28 Jan 2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Server Standalone v0.1-alpha
 */
public class IDGeneratorRequestProcessor implements ObjectProcessor<IDGeneratorRequest> {

	private static final long ID_RANGE = 200;

	@Override
	public Class<IDGeneratorRequest> getInputClass() { return IDGeneratorRequest.class; }

	@Override
	public void process(IDGeneratorRequest input, long socketId, ObjectWriteProxy writeProxy) throws IOException {
		System.out.println("Received id generation request.");

		ConfigItem	currentId	= PersistenceManager.getInstance().getConfigItemById("currentMessageId");
		IDGenerator	generator	= new IDGenerator(Integer.parseInt(currentId.getValue()), ID_RANGE);
		currentId.setValue(String.valueOf(Integer.parseInt(currentId.getValue()) + ID_RANGE));
		PersistenceManager.getInstance().updateConfigItem(currentId);

		System.out.println("Sending new id generator " + generator);
		writeProxy.write(socketId, generator);
	}
}
